<?php
/**
 * @category    Interactiv4
 * @package     Interactiv4_MDirector
 * @copyright   Copyright (c) 2014 Interactiv4. (http://www.interactiv4.com)
 */
class Interactiv4_MDirector_Block_Adminhtml_System_Config_Form_Field_Map_List
    extends Mage_Adminhtml_Block_System_Config_Form_Field_Array_Abstract
{
    public function __construct()
    {
        $this->addColumn('list', array(
            'label' => Mage::helper('i4mdirector')->__('List'),
            'style' => 'width:120px',
        ));
        $this->addColumn('customer_group', array(
            'label' => Mage::helper('i4mdirector')->__('Customer Group'),
            'style' => 'width:120px',
        ));
        $this->_addAfter = false;
        $this->_addButtonLabel = Mage::helper('i4mdirector')->__('Add List');
        parent::__construct();
    }

    /**
     * Render array cell for prototypeJS template
     *
     * @param string $columnName
     * @return string
     */
    protected function _renderCellTemplate($columnName)
    {
        if (empty($this->_columns[$columnName])) {
            throw new Exception('Wrong column name specified.');
        }
        $column     = $this->_columns[$columnName];
        $elementName  = $this->getElement()->getName() . '[#{_id}][' . $columnName . ']';
        $extraParams = ' data-value="#{' . $columnName . '}" ' .
            (isset($column['style']) ? ' style="'.$column['style'] . '"' : '');

        if ($columnName == 'list') {
            return $this->getListSelectHtml($elementName, $extraParams);
        } elseif ($columnName == 'customer_group') {
            return $this->getCustomerGroupSelectHtml($elementName, $extraParams);
        } else {
            return parent::_renderCellTemplate($columnName);
        }
    }

    public function getListSelectHtml($name, $extraParams)
    {
        $select = $this->getLayout()->createBlock('adminhtml/html_select')
            ->setName($name)
            ->setExtraParams($extraParams)
            ->setClass('select select-map-list')
            ->setOptions(Mage::getSingleton('i4mdirector/system_config_source_list')->toOptionArray());

        return $select->getHtml();
    }

    public function getCustomerGroupSelectHtml($name, $extraParams)
    {
        $select = $this->getLayout()->createBlock('adminhtml/html_select')
            ->setName($name)
            ->setExtraParams($extraParams)
            ->setClass('select select-map-list')
            ->setOptions(Mage::getSingleton('i4mdirector/system_config_source_customer_group')->toOptionArray());

        return $select->getHtml();
    }

    /**
     * Render block HTML
     *
     * @return string
     */
    protected function _toHtml()
    {
        $html = parent::_toHtml();
        $html .= Mage::helper('adminhtml/js')->getScript(
            "$$('.select-map-list').each(function(el){ el.value = el.readAttribute('data-value'); });\n"
        );

        return $html;
    }
}
