<?php
/**
 * @category    Interactiv4
 * @package     Interactiv4_MDirector
 * @copyright   Copyright (c) 2014 Interactiv4. (http://www.interactiv4.com)
 */ 
class Interactiv4_MDirector_Helper_Data extends Mage_Core_Helper_Abstract 
{
    const XML_PATH_ENABLED                          = 'i4mdirector/general/active';
    const XML_PATH_PIXEL_ENABLED                    = 'i4mdirector/pixel/active';
    const XML_PATH_SUBSCRIPTION_SEND_WELCOME_EMAIL  = 'i4mdirector/subscription/send_welcome_email';
    const XML_PATH_UNSUBSCRIPTION_SYNC_ENABLED      = 'i4mdirector/unsubscription_sync/enabled';
    const XML_PATH_UNSUBSCRIPTION_SYNC_LAST_DATE    = 'i4mdirector/unsubscription_sync/last_date';

    /**
     * Check if module is enabled
     *
     * @return bool
     */
    public function isEnabled()
    {
        return Mage::getStoreConfigFlag(self::XML_PATH_ENABLED);
    }

    /**
     * Check if pixel is enabled
     *
     * @return bool
     */
    public function isPixelEnabled()
    {
        return $this->isEnabled() && Mage::getStoreConfigFlag(self::XML_PATH_PIXEL_ENABLED);
    }

    /**
     * Check if can send mdirector welcome email
     * @return bool
     */
    public function sendMDirectorWelcomeEmail()
    {
        return Mage::getStoreConfigFlag(self::XML_PATH_SUBSCRIPTION_SEND_WELCOME_EMAIL);
    }

    /**
     * Check if can sync unsubscriptions
     *
     * @return bool
     */
    public function canSyncUnsubscription()
    {
        return $this->isEnabled() && Mage::getStoreConfigFlag(self::XML_PATH_UNSUBSCRIPTION_SYNC_ENABLED);
    }

    /**
     * Last sync date
     *
     * @return string
     */
    public function getLastSyncDate()
    {
        return Mage::getStoreConfig(self::XML_PATH_UNSUBSCRIPTION_SYNC_LAST_DATE);
    }

    /**
     * Return mdirector dataId tracked
     *
     * @return string
     */
    public function getDataId()
    {
        return Mage::getModel('core/cookie')->get('mdirector');
    }

    /**
     * Return ListId
     *
     * @param int $customerGroupId
     * @return int
     */
    public function getListIdByCustomerGroupId($customerGroupId)
    {
        $listPerCustomerGroup = unserialize(Mage::getStoreConfig('i4mdirector/general/map_list_per_customer_group'));
        foreach ($listPerCustomerGroup as $list) {
            if ($list['customer_group'] == $customerGroupId) {
                return $list['list'];
            }
        }

        return Mage::getStoreConfig('i4mdirector/general/default_list');
    }

    /**
     * Subscribe to list
     *
     * @param string $email
     * @param Mage_Customer_Model_Customer|int|string $customer
     * @param int $listId
     * @return bool
     */
    public function subscribe($email, $customer, $listId = null)
    {
        if (!$customer instanceof Mage_Customer_Model_Customer) {
            $customer = Mage::getModel('customer/customer')->load($customer);
        }
        $customerGroupId = $customer->getId() ? $customer->getGroupId() : Mage_Customer_Model_Group::NOT_LOGGED_IN_ID;
        $listId = $listId ? $listId : $this->getListIdByCustomerGroupId($customerGroupId);
        $sendWelcomeEmail = $this->sendMDirectorWelcomeEmail();
        $data = $this->getContactData($customer);
        $data = array_merge($data, array(
            'listId'                => $listId,
            'email'                 => $email,
            'send-notifications'    => (int)$sendWelcomeEmail,
        ));

        Mage::getSingleton('i4mdirector/api_unsubscription')->delete($data); // Need remove from MDirector unsubscription list before subscribe
        $result = Mage::getSingleton('i4mdirector/api_contact')->create($data);
        if ($result && $result['response'] == 'ok') {
            return true;
        }
        return false;
    }

    /**
     * Update Subscriber
     *
     * @param Mage_Customer_Model_Customer|int|string $customer
     * @param int $listId
     * @return bool
     */
    public function updateSubscriber($customer, $listId)
    {
        if (!$customer instanceof Mage_Customer_Model_Customer) {
            $customer = Mage::getModel('customer/customer')->load($customer);
        }
        $data = array(
            'email'         => $customer->getEmail(),
            'listId'        => $listId,
        );
        $contact = Mage::getSingleton('i4mdirector/api_contact')->fetch($data);
        if ($contact && $contact['response'] == 'ok') {
            $data['conId'] = $contact['data']['conId'];
            $data = array_merge($data, $this->getContactData($customer));
            $result = Mage::getSingleton('i4mdirector/api_contact')->update($data);
            if ($result && $result['response'] == 'ok') {
                return true;
            }
        }
        return false;
    }

    /**
     * Unsubscribe
     *
     * @param string $email
     * @return bool
     */
    public function unsubscribe($email)
    {
        $data = array(
            'email'         => $email,
            'unsubscribe'   => true,
            'reason'        => $this->__('Unsubscription'),
        );
        $result = Mage::getSingleton('i4mdirector/api_contact')->delete($data);
        if ($result && $result['response'] == 'ok') {
            return true;
        }
        return false;
    }

    /**
     * Remove contact from list
     *
     * @param string $email
     * @param int $listId
     * @return bool
     */
    public function unsubscribeFromList($email, $listId)
    {
        $data = array(
            'email'         => $email,
            'listId'        => $listId,
        );
        $contact = Mage::getSingleton('i4mdirector/api_contact')->fetch($data);
        if ($contact && $contact['response'] == 'ok') {
            $data = array(
                'conId'         => $contact['data']['conId'],
                'listId'        => $listId,
                'unsubscribe'   => false,
                'reason'        => $this->__('Unsubscription from List'),
            );
            $result = Mage::getSingleton('i4mdirector/api_contact')->delete($data);
            if ($result && $result['response'] == 'ok') {
                return true;
            }
        }
        return false;
    }

    /**
     * Extract Contact Data from Customer
     *
     * @param Mage_Customer_Model_Customer $customer
     * @return array
     */
    public function getContactData($customer)
    {
        $data = array();
        $customerAddress = $customer->getDefaultBillingAddress();
        if (!$customerAddress) {
            $customerAddress = Mage::getModel('customer/address');
        }

        $attributes = unserialize(Mage::getStoreConfig('i4mdirector/general/map_contact_attribute'));
        foreach ($attributes as $attribute) {
            $key = $attribute['contact_attribute'];
            switch ($attribute['customer_attribute']) {
                case 'street':
                    $data[$key] = trim(implode(", ", $customerAddress->getStreetFull()));
                    break;
                case 'region':
                    $data[$key] = $customerAddress->getRegion();
                    break;
                case 'country':
                    $data[$key] = $customerAddress->getCountry();
                    break;
                case 'company':
                case 'city':
                case 'postcode':
                case 'telephone':
                case 'fax':
                    $data[$key] = $customerAddress->getData($attribute['customer_attribute']);
                    break;
                default:
                    $data[$key] = $customer->getData($attribute['customer_attribute']);
                    break;
            }
        }
        return $data;
    }
}
