<?php
require Mage::getModuleDir('', 'Interactiv4_MDirector') . '/vendor/autoload.php';

/**
 * @category    Interactiv4
 * @package     Interactiv4_MDirector
 * @copyright   Copyright (c) 2014 Interactiv4. (http://www.interactiv4.com)
 */
class Interactiv4_MDirector_Model_Api_Abstract
{
    protected $_resource;

    /**
     * Return Zend_Oauth_Client instance
     *
     * @return \MDOAuth\OAuth2\Client\MDirector
     */
    public function getClient()
    {
        return (new \MDOAuth\OAuth2\Client\MDirector\Factory())->create(
            $this->getConsumerKey(),
            $this->getConsumerSecret()
        );
    }

    /**
     * Send the HTTP request and return an HTTP response array
     *
     * @param string $url
     * @param array $responseData
     * @param string $method
     * @return array
     */
    public function request($url, $data = array(), $method = 'GET')
    {
        Mage::log("CALLING URL {$url} METHOD {$method}", null, 'mic.log', true);
        Mage::log($data, null, 'mic.log', true);

        $client = $this->getClient();
        $response = $client->setUri($url)
            ->setMethod($method)
            ->setParameters($data)
            ->request();

        $responseData = $response->getBody()->getContents();
        Mage::log($responseData, null, 'mic.log', true);
        return json_decode($responseData, true);
    }

    /**
     * Return API Consumer Key
     *
     * @return string
     */
    public function getConsumerKey()
    {
        return Mage::getStoreConfig('i4mdirector/general/consumer_key');
    }

    /**
     * Return API Consumer Secret
     *
     * @return string
     */
    public function getConsumerSecret()
    {
        return Mage::getStoreConfig('i4mdirector/general/consumer_secret');
    }

    /**
     * Return Base URL
     *
     * @return string
     */
    public function getBaseUrl()
    {
        return Mage::getStoreConfig('i4mdirector/general/base_url');
    }

    /**
     * Return API Resource
     *
     * @return string
     */
    public function getResource()
    {
        return $this->_resource;
    }

    /**
     * Return Full Resource URL
     *
     * @return string
     */
    public function getUrl()
    {
        return $this->getBaseUrl() . '/' . $this->getResource();
    }

    /**
     * @return bool
    */
    public function isLoggedIn()
    {
        return $this->getConsumerKey() && $this->getConsumerSecret();
    }
}
