<?php
/**
 * @category    Interactiv4
 * @package     Interactiv4_MDirector
 * @copyright   Copyright (c) 2014 Interactiv4. (http://www.interactiv4.com)
 */
class Interactiv4_MDirector_Model_Observer
{
    public function subscriberSaveBefore(Varien_Event_Observer $observer)
    {
        if (!Mage::helper('i4mdirector')->isEnabled()) {
            return;
        }

        /* @var $subscriber Mage_Newsletter_Model_Subscriber */
        $subscriber = $observer->getEvent()->getSubscriber();
        if ($subscriber->getIsStatusChanged()) {
            if ($subscriber->getStatus() == Mage_Newsletter_Model_Subscriber::STATUS_SUBSCRIBED) {
                if (Mage::helper('i4mdirector')->sendMDirectorWelcomeEmail()) {
                    $subscriber->setImportMode(true);
                }
                Mage::helper('i4mdirector')->subscribe($subscriber->getEmail(), $subscriber->getCustomerId());
            } elseif ($subscriber->getStatus() == Mage_Newsletter_Model_Subscriber::STATUS_UNSUBSCRIBED) {
                Mage::helper('i4mdirector')->unsubscribe($subscriber->getEmail(), $subscriber->getCustomerId());
            }
        }
    }

    public function subscriberDeleteAfter(Varien_Event_Observer $observer)
    {
        if (!Mage::helper('i4mdirector')->isEnabled()) {
            return;
        }

        /* @var $subscriber Mage_Newsletter_Model_Subscriber */
        $subscriber = $observer->getEvent()->getSubscriber();
        Mage::helper('i4mdirector')->unsubscribe($subscriber->getEmail());
    }

    public function customerSaveAfter(Varien_Event_Observer $observer)
    {
        if (!Mage::helper('i4mdirector')->isEnabled()) {
            return;
        }
        /* @var $customer Mage_Customer_Model_Customer */
        $customer = $observer->getEvent()->getCustomer();

        if (Mage::registry('customer_account_createpost' . $customer->getId())) {
            return;
        }

        $listId = Mage::helper('i4mdirector')->getListIdByCustomerGroupId($customer->getGroupId());
        $oldListId = false;
        if (!$customer->getOrigData('email')) {
            $oldListId = Mage::helper('i4mdirector')
                ->getListIdByCustomerGroupId(Mage_Customer_Model_Group::NOT_LOGGED_IN_ID);
        } elseif ($customer->getOrigData('group_id')) {
            $oldListId = Mage::helper('i4mdirector')
                ->getListIdByCustomerGroupId($customer->getOrigData('group_id'));
        }

        if ($oldListId == $listId) {
            Mage::helper('i4mdirector')->updateSubscriber($customer, $listId);
        } else {
            Mage::helper('i4mdirector')->unsubscribeFromList($customer->getEmail(), $oldListId);
            Mage::helper('i4mdirector')->subscribe($customer->getEmail(), $customer, $listId);
        }

        Mage::register('customer_account_createpost' . $customer->getId(), true);
    }

    public function syncUnsubscription()
    {
        if (!Mage::helper('i4mdirector')->canSyncUnsubscription()) {
            return;
        }

        $currentDate = Varien_Date::now();

        $lastSyncDate = Mage::helper('i4mdirector')->getLastSyncDate();
        if (!$lastSyncDate) {
            $lastSyncDate = '2015-01-01';
        }
        $startDate = Mage::app()->getLocale()->date($lastSyncDate, Varien_Date::DATETIME_INTERNAL_FORMAT, null, false)
            ->toString(Varien_Date::DATE_INTERNAL_FORMAT);
        $endDate = Varien_Date::now(true);

        $result =  Mage::getSingleton('i4mdirector/api_unsubscription')->findByDate($startDate, $endDate);
        if (count($result)) {
            foreach ($result as $item) {
                $subscriber = Mage::getModel('newsletter/subscriber')->loadByEmail($item['Contact']);
                if ($subscriber->getId() && $subscriber->getStatus() != Mage_Newsletter_Model_Subscriber::STATUS_UNSUBSCRIBED) {
                    $subscriber->unsubscribe();
                }
            }
        }

        $config = new Mage_Core_Model_Config();
        $config->saveConfig('i4mdirector/unsubscription_sync/last_date', $currentDate);
    }
}
